#  !/usr/bin/env python

import os
from concatenator.utils import read_arguments

class Concatenator(object):
    """
    A class used to concatenate two input text files into a single output file.

    Parameters
    ----------
    input_path_1 : str
        The file path of the first input file.
    input_path_2 : str
        The file path of the second input file.
    output_path : str
        The directory path where the output file will be saved.
    output_name : str, optional
        The name of the output file. If None, the default name 'document3.txt' will be used.
    """

    def __init__(self, input_path_1, input_path_2, output_path, output_name):
        self.input_path_1 = input_path_1
        self.input_path_2 = input_path_2
        if output_name is None:
            self.output_file = os.path.join(output_path, "document3.txt")
        else:
            self.output_file = os.path.join(output_path, output_name)

    def compute(self):
        """
        Concatenates the contents of the two input files and writes the result to the output file.

        Returns
        -------
        None
        """
        doc1 = open(self.input_path_1).read()
        doc2 = open(self.input_path_2).read()

        # Create a new doc and concatenate both files
        with open(self.output_file, "a") as doc3:
            doc3.write(doc1)
            doc3.write(doc2)

        return None


def run():
    """
    Executes the concatenation process by reading input arguments and invoking the Concatenator class.

    Returns
    -------
    None
    """
    # Read the inputs and output arguments and check if they exist
    input1, input2, output_path, output_name = read_arguments()

    # Concatenate them using the class Concatenator
    concatenate = Concatenator(input1, input2, output_path, output_name)
    concatenate.compute()


if __name__ == "__main__":
    run()
