#!/usr/bin/env python

import os
import argparse


def read_arguments():
    """
    Parses and validates the command line arguments.

    Returns
    -------
    Namespace
        The parsed arguments containing input file paths, output directory, and optional output file name.
    """
    parser = argparse.ArgumentParser(description='Ejemplo de argparse')

    # Define the inputs (-i and -g) and the output (-o)
    parser.add_argument("-i", "--input1", type=str, required=True,
                        help="The path of the first input file")
    parser.add_argument("-g", "--input2", type=str, required=True,
                        help="The path of the second input file")
    parser.add_argument("-o", "--output", type=str, required=True,
                        help="The path of the output directory")
    parser.add_argument("-n", "--doc_name", type=str, required=False,
                        help="The name of the output file (optional)")

    args = parser.parse_args()
    check(args)
    return args.input1, args.input2, args.output, args.doc_name


def check(args):
    """
    Validates the existence of the input files and the output directory.

    Parameters
    ----------
    args : Namespace
        The arguments parsed from the command line, containing input file paths and output directory.

    Raises
    ------
    FileNotFoundError
        If either of the input files or the output directory does not exist.
    """
    # Confirm that both input files exist
    if not os.path.exists(args.input1):
        raise FileNotFoundError(f"The file from the first input does not exist {args.input1}.")
    if not os.path.exists(args.input2):
        raise FileNotFoundError(f"The file from the second input does not exist {args.input2}.")
    # Confirm that the output directory exists
    if not os.path.isdir(args.output):
        raise FileNotFoundError(f"The output directory does not exist {args.output}.")
